@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of HepMC
-// Copyright (C) 2014-2020 The HepMC collaboration (see AUTHORS for details)
+// Copyright (C) 2014-2023 The HepMC collaboration (see AUTHORS for details)
 //
 /**
  *  @file LHEFAttributes.cc
@@ -23,19 +23,21 @@ bool HEPRUPAttribute::from_string(const std::string &att) {
     bool found = false;
     clear();
     tags = LHEF::XMLTag::findXMLTags(att);
-    for ( int i = 0, N = tags.size(); i < N; ++i )
+    for ( int i = 0, N = tags.size(); i < N; ++i ) {
         if ( tags[i]->name == "init" ) {
             heprup = LHEF::HEPRUP(*tags[i], 3);
             found = true;
         }
+    }
     return found;
 }
 
 bool HEPRUPAttribute::to_string(std::string &att) const {
     std::ostringstream os;
     if ( heprup.NPRUP ) heprup.print(os);
-    for ( int i = 0, N = tags.size(); i < N; ++i )
+    for ( int i = 0, N = tags.size(); i < N; ++i ) {
         if ( heprup.NPRUP == 0 || tags[i]->name != "init" ) tags[i]->print(os);
+    }
     att = os.str();
     return true;
 }
@@ -49,19 +51,23 @@ void HEPEUPAttribute::clear() {
 bool HEPEUPAttribute::from_string(const std::string &att) {
     clear();
     tags = LHEF::XMLTag::findXMLTags(att);
-    for ( int i = 0, N = tags.size(); i < N; ++i )
-        if ( tags[i]->name == "event" || tags[i]->name == "eventgroup")
+    for ( int i = 0, N = tags.size(); i < N; ++i ) {
+        if ( tags[i]->name == "event" || tags[i]->name == "eventgroup") {
             return true;
+        }
+    }
     return false;
 }
 
 bool HEPEUPAttribute::to_string(std::string &att) const {
     std::ostringstream os;
     if ( hepeup.heprup ) hepeup.print(os);
-    for ( int i = 0, N = tags.size(); i < N; ++i )
+    for ( int i = 0, N = tags.size(); i < N; ++i ) {
         if ( !hepeup.heprup ||
-                (tags[i]->name != "event" && tags[i]->name != "eventgroup") )
+                (tags[i]->name != "event" && tags[i]->name != "eventgroup") ) {
             tags[i]->print(os);
+        }
+    }
     att = os.str();
     return true;
 }
@@ -70,11 +76,12 @@ bool HEPEUPAttribute::init() {
     std::shared_ptr<HEPRUPAttribute> hepr =
         event()->attribute<HEPRUPAttribute>("HEPRUP");
     bool found = false;
-    for ( int i = 0, N = tags.size(); i < N; ++i )
+    for ( int i = 0, N = tags.size(); i < N; ++i ) {
         if ( tags[i]->name == "event" || tags[i]->name == "eventgroup" ) {
             hepeup = LHEF::HEPEUP(*tags[i], hepr->heprup);
             found = true;
         }
+    }
     return found;
 }
 
